pub enum Error {
EmptyStayFactId,
EmptyServiceDemandFactId,
EmptyDemandUnits,
EmptyProjectionVersion,
}Expand description
Validation failures returned by analytics domain constructors.
Variants
EmptyStayFactId
Signals that stay fact id was blank or missing during analytics validation.
EmptyServiceDemandFactId
Signals that service demand fact id was blank or missing during analytics validation.
EmptyDemandUnits
Signals that demand units was blank or missing during analytics validation.
EmptyProjectionVersion
Signals that projection version was blank or missing during analytics validation.